@@ -10,20 +10,20 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.02';
+$VERSION = '0.03';
 $DATE = '2003/07/11';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/File_PM2File.pm' => [qw(0.02 2003/07/11), 'revised 0.01'],
-    'MANIFEST' => [qw(0.02 2003/07/11), 'generated, replaces 0.01'],
-    'Makefile.PL' => [qw(0.02 2003/07/11), 'generated, replaces 0.01'],
-    'README' => [qw(0.02 2003/07/11), 'generated, replaces 0.01'],
-    'lib/File/PM2File.pm' => [qw(1.11 2003/07/11), 'revised 1.1'],
-    't/File/PM2File.d' => [qw(0.01 2003/07/07), 'unchanged'],
-    't/File/PM2File.pm' => [qw(0.01 2003/06/07), 'unchanged'],
-    't/File/PM2File.t' => [qw(0.01 2003/07/07), 'unchanged'],
+    'lib/Docs/Site_SVD/File_PM2File.pm' => [qw(0.03 2003/07/11), 'revised 0.02'],
+    'MANIFEST' => [qw(0.03 2003/07/11), 'generated, replaces 0.02'],
+    'Makefile.PL' => [qw(0.03 2003/07/11), 'generated, replaces 0.02'],
+    'README' => [qw(0.03 2003/07/11), 'generated, replaces 0.02'],
+    'lib/File/PM2File.pm' => [qw(1.11 2003/07/11), 'unchanged'],
+    't/File/PM2File.d' => [qw(0.02 2003/07/11), 'revised 0.01'],
+    't/File/PM2File.pm' => [qw(0.02 2003/07/11), 'revised 0.01'],
+    't/File/PM2File.t' => [qw(0.08 2003/07/11), 'revised 0.07'],
 
 );
 
@@ -50,9 +50,9 @@ use vars qw(%INVENTORY);
 
   File::PM2File - Convert PM specifications to file specifications
 
- Revision: A
+ Revision: B
 
- Version: 0.02
+ Version: 0.03
 
  Date: 2003/07/11
 
@@ -88,7 +88,7 @@ to the file specification for the current site operating system.
 
 =head2 1.3 Document overview.
 
-This document releases File::PM2File version 0.02
+This document releases File::PM2File version 0.03
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -104,8 +104,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/File-PM2File-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.02
+   http://www.softwarediamonds/packages/File-PM2File-0.03
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.03
 
 
 Restrictions regarding duplication and license provisions
@@ -173,14 +173,14 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/File_PM2File.pm                            0.02    2003/07/11 revised 0.01
- MANIFEST                                                     0.02    2003/07/11 generated, replaces 0.01
- Makefile.PL                                                  0.02    2003/07/11 generated, replaces 0.01
- README                                                       0.02    2003/07/11 generated, replaces 0.01
- lib/File/PM2File.pm                                          1.11    2003/07/11 revised 1.1
- t/File/PM2File.d                                             0.01    2003/07/07 unchanged
- t/File/PM2File.pm                                            0.01    2003/06/07 unchanged
- t/File/PM2File.t                                             0.01    2003/07/07 unchanged
+ lib/Docs/Site_SVD/File_PM2File.pm                            0.03    2003/07/11 revised 0.02
+ MANIFEST                                                     0.03    2003/07/11 generated, replaces 0.02
+ Makefile.PL                                                  0.03    2003/07/11 generated, replaces 0.02
+ README                                                       0.03    2003/07/11 generated, replaces 0.02
+ lib/File/PM2File.pm                                          1.11    2003/07/11 unchanged
+ t/File/PM2File.d                                             0.02    2003/07/11 revised 0.01
+ t/File/PM2File.pm                                            0.02    2003/07/11 revised 0.01
+ t/File/PM2File.t                                             0.08    2003/07/11 revised 0.07
 
 
 =head2 3.3 Changes
@@ -278,7 +278,7 @@ t/Test/TestUtil/TestUtil....NOK 18# Test 18 got: '$VAR1 = '\\=head1 Title Page
   File::PM2File - Convert PM specifications to file specifications
 
 
- Revision: A
+ Revision: B
 
 [snip]
 
@@ -450,8 +450,8 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/File-PM2File-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.02
+   http://www.softwarediamonds/packages/File-PM2File-0.03
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.03
 
 
 =item Prerequistes.
@@ -569,11 +569,11 @@ __DATA__
 DISTNAME: File-PM2File^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.02^
+VERSION : 0.03^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.01^
-REVISION: A^
+PREVIOUS_RELEASE: 0.02^
+REVISION: B^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 
